/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.TestHelper;
import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;
import junit.framework.TestCase;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;

/**
 * <p>
 * Unit test cases for RegexMatcher.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class RegexMatcherTests extends TestCase {
    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.matcher.unittest";

    /**
     * The config file for this test.
     */
    private static final String CONFIG_FILE = "matcher/matcher_config.xml";

    /**
     * An RegexMatcher instance to test.
     */
    private RegexMatcher matcher = null;

    /**
     * Load the configuration before testing.
     *
     * @throws Exception to JUnit
     */
    protected void setUp() throws Exception {
        TestHelper.loadConfigFile(CONFIG_FILE, NAMESPACE);
        matcher = new RegexMatcher(Pattern.compile("^.*\\.txt$"));
    }

    /**
     * Remove the configuration after testing.
     *
     * @throws Exception to JUnit
     */
    protected void tearDown() throws Exception {
        TestHelper.removeNamespace(NAMESPACE);
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(String).
     * </p>
     */
    public void testRegexMatcher1() {
        assertTrue("Unable to instantiate RegexMatcher.",
            new RegexMatcher(Pattern.compile("foo")) instanceof FileNameMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(String) with null argument. NullPointerException
     * should be thrown.
     * </p>
     */
    public void testRegexMatcher2() {
        try {
            new RegexMatcher((Pattern) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(Property).
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher3() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "regex_matcher");
        assertTrue("Unable to instantiate RegexMatcher.",
            new RegexMatcher(property) instanceof FileNameMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(Property) with null argument.
     * NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher4() throws Exception {
        try {
            new RegexMatcher((Property) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(Property) with invalid property.
     * ConfigurationException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher5() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "regex_matcher_invalid1");

        try {
            new RegexMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(Property) with invalid property.
     * ConfigurationException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher6() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "regex_matcher_invalid2");

        try {
            new RegexMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(Property) with invalid property.
     * ConfigurationException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher7() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "regex_matcher_invalid3");

        try {
            new RegexMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(List).
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher8() throws Exception {
        List patterns = new ArrayList();
        patterns.add(Pattern.compile("^.*\\.txt$"));
        patterns.add(Pattern.compile("^.*\\.java$"));
        assertTrue("Unable to instantiate RegexMatcher.",
            new RegexMatcher(patterns) instanceof FileNameMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(List) with null argument. NullPointerException
     * should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher9() throws Exception {
        try {
            new RegexMatcher((List) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(List) with empty list. IllegalArgumentException
     * should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher10() throws Exception {
        try {
            new RegexMatcher(new ArrayList());
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - RegexMatcher(List) with invalid list.
     * IllegalArgumentException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testRegexMatcher11() throws Exception {
        List patterns = new ArrayList();
        patterns.add(new ArrayList());

        try {
            new RegexMatcher(patterns);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method with null argument. NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch1() throws Exception {
        try {
            matcher.match((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method of a general pattern mather.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch2() throws Exception {

        assertTrue("The result should be true", matcher.match(new File("test.txt")));
        assertFalse("The result should be false", matcher.match(new File("test.java")));
        assertTrue("The result should be true", matcher.match(new File("tests.java.txt")));
        assertFalse("The result should be false", matcher.match(new File("tests.text.java")));
        assertFalse("The result should be false", matcher.match(new File("")));
        assertTrue("The result should be true", matcher.match(new File(".txt")));
        assertFalse("The result should be false", matcher.match(new File("txt")));
    }

    /**
     * <p>
     * Tests the match method of multi-pattern mather.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch3() throws Exception {
        // create a matcher that accepts "foo" and "".
        List patterns = new ArrayList();
        patterns.add(Pattern.compile("^.*\\.txt$"));
        patterns.add(Pattern.compile("^.*\\.java$"));
        matcher = new RegexMatcher(patterns);

        assertTrue("The result should be true", matcher.match(new File("test.java")));
        assertTrue("The result should be true", matcher.match(new File("test.txt")));
        assertFalse("The result should be false", matcher.match(new File("test.cs")));
    }

    /**
     * <p>
     * Tests the match method of multi-pattern mather.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch4() throws Exception {
        // create a matcher that accepts "foo" and "".
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "regex_matcher");
        matcher = new RegexMatcher(property);

        assertTrue("The result should be true", matcher.match(new File("test.java")));
        assertTrue("The result should be true", matcher.match(new File("test.txt")));
        assertFalse("The result should be false", matcher.match(new File("test.cs")));

    }
}
