/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.reporting;

import com.topcoder.file.statistics.Metric;
import com.topcoder.file.statistics.StatsResult;
import junit.framework.TestCase;
import java.util.List;


/**
 * <p>
 * Unit test cases for StatsCollection.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class StatsCollectionTests extends TestCase {
    /**
     * A StatsCollection instance to test.
     */
    private StatsCollection collection = null;

    /**
     * Creates a StatsCollection instance.
     */
    protected void setUp() {
        collection = new StatsCollection();
    }

    /**
     * <p>
     * Verifies the constructor.
     * </p>
     */
    public void testStatsCollection1() {
        assertNotNull("Unable to instantiate StatsCollection.", new StatsCollection());
    }

    /**
     * <p>
     * Tests the add method.
     * </p>
     */
    public void testAdd1() {
        StatsResult result1 = new StatsResult();
        result1.setStat(new Metric("M1", "M1", "M1"), 10);
        result1.setStat(new Metric("M2", "M2", "M2"), 20);

        StatsResult result2 = new StatsResult();
        result2.setStat(new Metric("M2", "M2", "M2"), 30);
        result2.setStat(new Metric("M3", "M3", "M3"), 0);

        collection.add("foo", result1);
        collection.add("foo", result2);

        StatsResult result3 = collection.get("foo");

        assertEquals("the result should be 10", 10, result3.getStat(new Metric("M1", "M1", "M1")));
        assertEquals("the result should be 10", 50, result3.getStat(new Metric("M2", "M2", "M2")));
        assertEquals("the result should be 10", 0, result3.getStat(new Metric("M3", "M3", "M3")));
    }

    /**
     * <p>
     * Tests the add method.
     * </p>
     */
    public void testAdd2() {
        StatsResult result1 = new StatsResult();
        result1.setStat(new Metric("M1", "M1", "M1"), 10);
        result1.setStat(new Metric("M2", "M2", "M2"), 20);

        StatsResult result2 = new StatsResult();
        result2.setStat(new Metric("M2", "M2", "M2"), 30);
        result2.setStat(new Metric("M3", "M3", "M3"), 0);

        collection.add("foo", result1);
        collection.add("bar", result2);

        StatsResult result3 = collection.get("foo");

        assertEquals("the result should be 10", 10, result3.getStat(new Metric("M1", "M1", "M1")));
        assertEquals("the result should be 10", 20, result3.getStat(new Metric("M2", "M2", "M2")));

        StatsResult result4 = collection.get("bar");

        assertEquals("the result should be 10", 30, result4.getStat(new Metric("M2", "M2", "M2")));
        assertEquals("the result should be 10", 0, result4.getStat(new Metric("M3", "M3", "M3")));
    }

    /**
     * <p>
     * Tests the add method with empty string. IllegalArgumentException should be thrown.
     * </p>
     */
    public void testAdd3() {
        try {
            collection.add(" ", new StatsResult());
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the add method with null argument. NullPointerException should be thrown.
     * </p>
     */
    public void testAdd4() {
        try {
            collection.add(null, new StatsResult());
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the add method with null argument. NullPointerException should be thrown.
     * </p>
     */
    public void testAdd5() {
        try {
            collection.add("foo", null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the get method.
     * </p>
     */
    public void testGet1() {
        assertNull("null should be returned.", collection.get("no"));
    }

    /**
     * <p>
     * Tests the get method.
     * </p>
     */
    public void testGet2() {
        StatsResult result1 = new StatsResult();
        collection.add("foo", result1);

        StatsResult result2 = collection.get("foo");
        assertNotNull("null should be returned.", result2);
        assertFalse("the reference should not be same", result1 == result2);
    }

    /**
     * <p>
     * Tests the get method with empty string. IllegalArgumentException should be thrown.
     * </p>
     */
    public void testGet3() {
        try {
            collection.get(" ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the get method with null argument. NullPointerException should be thrown.
     * </p>
     */
    public void testGet4() {
        try {
            collection.get(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // seccuss
        }
    }

    /**
     * <p>
     * Tests the getAllKeys method.
     * </p>
     */
    public void testGetAllKeys1() {
        assertEquals("size should be 0", 0, collection.getAllKeys().size());
    }

    /**
     * <p>
     * Tests the getAllKeys method.
     * </p>
     */
    public void testGetAllKeys2() {
        collection.add("abcB", new StatsResult());
        collection.add("ABCC", new StatsResult());
        collection.add("1234", new StatsResult());
        collection.add("ABCa", new StatsResult());
        collection.add("abc", new StatsResult());

        List keys = collection.getAllKeys();

        assertEquals("size should be 0", 5, keys.size());
        assertEquals("the first should be 1234", "1234", keys.get(0));
        assertEquals("the second should be abc", "abc", keys.get(1));
        assertEquals("the third should be ABCa", "ABCa", keys.get(2));
        assertEquals("the fourth should be abcB", "abcB", keys.get(3));
        assertEquals("the fifth should be ABCC", "ABCC", keys.get(4));
    }

    /**
     * <p>
     * Tests the clear method.
     * </p>
     */
    public void testClear() {
        collection.add("abcB", new StatsResult());
        collection.add("ABCC", new StatsResult());
        collection.clear();
        assertEquals("size should be 0", 0, collection.getAllKeys().size());
    }
}
