/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.util.config.Property;
import java.io.File;


/**
 * <p>
 * AnyFileMatcher is a trivial implementation that matches any file.
 * </p>
 *
 * <p>
 * Configuration: Does not need any configuration. Constructor maintained for reflection purpose.
 * </p>
 *
 * <p>
 * Thread Safety: This class is stateless and thread-safe.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public class AnyFileMatcher implements FileMatcher {
    /**
     * <p>
     * Default constructor. Does nothing.
     * </p>
     */
    public AnyFileMatcher() {
        // Empty
    }

    /**
     * <p>
     * Reflection contract. Does nothing.
     * </p>
     *
     * @param property the property to configure from
     *
     * @throws NullPointerException if property is null
     */
    public AnyFileMatcher(Property property) {
        MatcherHelper.checkNull(property, "property");
    }

    /**
     * <p>
     * Always returns true since this matcher matches any file.
     * </p>
     *
     * @param file the file to match
     *
     * @return always true
     *
     * @throws NullPointerException if file is null
     */
    public boolean match(File file) {
        MatcherHelper.checkNull(file, "file");

        return true;
    }
}
