/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics;

import com.topcoder.util.config.ConfigManager;


/**
 * <p>
 * A Helper class provides some useful methods, such as loading config file, etc.
 * Note: this class is public since it will be used in several packages.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TestHelper {

    /**
     * Private constructor to prevent this class be instantiated.
     */
    private TestHelper() {
        // empty
    }

    /**
     * Load the configuration from the given file to the given namespace.
     *
     * @param namespace the namespace to load
     * @param file the config file to add
     * @throws Exception to JUnit
     */
    public static void loadConfigFile(String file, String namespace) throws Exception {

        // clear the namespace first
        removeNamespace(namespace);

        // load the configuration
        ConfigManager.getInstance().add(file);

    }

    /**
     * Remove the given namespace form config manager.
     *
     * @param namespace the namespace to remove
     * @throws Exception to JUnit
     */
    public static void removeNamespace(String namespace) throws Exception {
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(namespace)) {
            configManager.removeNamespace(namespace);
        }
    }


}
