/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.extractor;

import java.io.File;
import java.io.IOException;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.util.config.Property;

public class DummyRARExtractor extends ArchiveExtractorBase {
	
	/**
	 * <p>
	 * Constructor with all arguments propagated to base constructor.
	 * </p>
	 * 
	 * @param matcher the file matcher
	 * @param pathSeparator the path separator
	 * @exception NullPointerException if either matcher is null
	 */
    public DummyRARExtractor(FileMatcher matcher, char pathSeparator) {
    	super(matcher, pathSeparator); 
    } 

	/**
	 * <p>
	 * Does nothing more than propagate to base constructor.
	 * </p>
	 * 
	 * @param property the property node to configure from
	 * @exception NullPointerException if property is null
	 * @exception ConfigurationException if config error occurs
	 */
    public DummyRARExtractor(Property property) throws ConfigurationException {
    	super(property);
    } 

	/**
	 * <p>
	 * A dummy implementation. Simply create an empty dummy.file in given target directory.
	 * </p>
	 * 
	 * @param source the sourec archive file
	 * @param target the target directory
	 * @exception NullPointerException if either source or target is null
	 * @exception IOException if io operation fails
	 */
	public void extract(File source, File target) throws IOException {
    	if (source == null) {
    		throw new NullPointerException("source should no be null");
    	}
    	if (target == null) {
    		throw new NullPointerException("target should no be null");
    	}
    	
		File file = new File(target, "dummy.file");
		file.createNewFile();
	}

}
