/*
 * $(#)ExtendedFileStatisticsTests.java		Sep 6, 2005
 * 
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.ExtendedFileStatistics;
import com.topcoder.util.config.ConfigManager;

/**
 * This test case contains the failure tests for the <code>ExtendedFileStatistics</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class ExtendedFileStatisticsTests extends TestCase {

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files";

    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.failuretests";

    /**
     * An ExtendedFileStatistics instance to test.
     */
    private ExtendedFileStatistics fileStatistics = null;

    /**
     * Creates an ExtendedFileStatistics instance.
     *
     * @throws Exception in case anything goes wrong
     */
    protected void setUp() throws Exception {
        fileStatistics = new ExtendedFileStatistics();
    }

    /**
     * Checks whether the constructor - ExtendedFileStatistics(String) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testExtendedFileStatistics1() throws Exception {
        try {
            new ExtendedFileStatistics(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor - ExtendedFileStatistics(String) properly throws
     * IllegalArgumentException for empty String argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testExtendedFileStatistics2() throws Exception {
        try {
            new ExtendedFileStatistics(" ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor - ExtendedFileStatistics(String) properly throws
     * ConfigurationException for invalid configuration.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testExtendedFileStatistics3() throws Exception {
        final String CONFIG_FILE = "failuretests/invalid1.xml";
        // clear the namespace first
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
        // load the configuration
        ConfigManager.getInstance().add(CONFIG_FILE);

        try {
            new ExtendedFileStatistics(NAMESPACE);
            fail("ConfigurationException should be thrown.");
        } catch (ConfigurationException e) {
            // success
        } finally {
            if (configManager.existsNamespace(NAMESPACE)) {
                configManager.removeNamespace(NAMESPACE);
            }
        }
    }

    /**
     * Checks whether the constructor - ExtendedFileStatistics(String) properly throws
     * ConfigurationException for invalid configuration.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testExtendedFileStatistics4() throws Exception {
        final String CONFIG_FILE = "failuretests/invalid2.xml";
        // clear the namespace first
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
        // load the configuration
        ConfigManager.getInstance().add(CONFIG_FILE);

        try {
            new ExtendedFileStatistics(NAMESPACE);
            fail("ConfigurationException should be thrown.");
        } catch (ConfigurationException e) {
            // success
        } finally {
            if (configManager.existsNamespace(NAMESPACE)) {
                configManager.removeNamespace(NAMESPACE);
            }
        }
    }

    /**
     * Checks whether the method addFileProcessor(String) properly throws
     * NullPointerException for null argument.
     */
    public void testAddFileProcessor() {
        try {
            fileStatistics.addFileProcessor(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method removeFileProcessor(String) properly throws
     * NullPointerException for null argument.
     */
    public void testRemoveFileProcessor1() {
        try {
            fileStatistics.removeFileProcessor(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method removeFileProcessor(String) properly throws
     * IllegalArgumentException for empty String argument.
     */
    public void testRemoveFileProcessor2() {
        try {
            fileStatistics.removeFileProcessor(" ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }
    
    /**
     * Checks whether the method setReporting(StatsReporting) properly throws
     * NullPointerException for null argument.
     */
    public void testSetReporting() {
        try {
            fileStatistics.setReporting(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method processFile(File) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProccessFile() throws Exception {
        try {
            fileStatistics.processFile(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }
    
    /**
     * Checks whether the method processDirectory(File) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProcessDirectory1() throws Exception {
        try {
            fileStatistics.processDirectory(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method processDirectory(File) properly throws
     * IllegalArgumentException for invalid argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProcessDirectory2() throws Exception {
        try {
            fileStatistics.processDirectory(new File(BASE_PATH, "inexistent_dir"));
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the method processDirectory(File) properly throws
     * IllegalArgumentException for invalid argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProcessDirectory3() throws Exception {
        try {
            fileStatistics.processDirectory(new File(BASE_PATH, "valid.file"));
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the method processDirectory(File, boolean) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProcessDirectory4() throws Exception {
        try {
            fileStatistics.processDirectory(null, false);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method processDirectory(File) properly throws
     * IllegalArgumentException for invalid argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProcessDirectory5() throws Exception {
        try {
            fileStatistics.processDirectory(new File(BASE_PATH, "inexistent_dir"), false);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the method processDirectory(File) properly throws
     * IllegalArgumentException for invalid argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testProcessDirectory6() throws Exception {
        try {
            fileStatistics.processDirectory(new File(BASE_PATH, "valid.file"), false);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the method printReport(File) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testPrintReport1() throws Exception {
        try {
            fileStatistics.printReport(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method printReport(File) properly throws
     * IOException for invalid file argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testPrintReport2() throws Exception {
        try {
            fileStatistics.printReport(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }
    
}
