/*
 * $(#)ExtensionMatcherTests.java		Sep 6, 2005
 * 
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests.matcher;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import junit.framework.TestCase;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.matcher.ExtensionMatcher;
import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;

/**
 * This test case contains the failure tests for the <code>ExtensionMatcherTests</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class ExtensionMatcherTests extends TestCase {

    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.matcher.failuretests";

    /**
     * The config file for this test.
     */
    private static final String CONFIG_FILE = "failuretests/matcher/config.xml";

    /**
     * An ExtensionMatcherTests instance to test.
     */
    private ExtensionMatcher matcher = null;

    /**
     * Load the configuration before testing.
     *
     * @throws Exception in cae anything goes wrong
     */
    protected void setUp() throws Exception {
        // clear the namespace first
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
        // load the configuration
        ConfigManager.getInstance().add(CONFIG_FILE);
        
        matcher = new ExtensionMatcher("txt");
    }

    /**
     * Remove the configuration after testing.
     *
     * @throws Exception in case anything goes wrong
     */
    protected void tearDown() throws Exception {
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
    }

    /**
     * Checks whether the constructor ExtensionMatcher(String) properly throws
     * NullPointerException for null argument.
     * 
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher1() throws Exception {
        try {
            new ExtensionMatcher((String)null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor ExtensionMatcher(Property) properly throws
     * NullPointerException for null argument.
     * 
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher2() throws Exception {
        try {
            new ExtensionMatcher((Property)null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor ExtensionMatcher(Property) properly throws
     * Configuration for invalid property - no values in "extensions" sub-property.
     * 
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher3() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "extension_invalid1");

        try {
            new ExtensionMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor ExtensionMatcher(Property) properly throws
     * Configuration for invalid property - no "extensions" sub-property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher4() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "extension_invalid2");

        try {
            new ExtensionMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor ExtensionMatcher(List) properly throws
     * NullPointerException for null argument.
     * 
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher5() throws Exception {
        try {
            new ExtensionMatcher((List)null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor ExtensionMatcher(List) properly throws
     * IllegalArgumentException for empty List argument.
     * 
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher6() throws Exception {
        try {
            new ExtensionMatcher(new ArrayList());
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }
    
    /**
     * Checks whether the constructor ExtensionMatcher(List) properly throws
     * IllegalArgumentException for List argument containing nulls.
     * 
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher7() throws Exception {
        List list = new ArrayList();
        list.add("");
        list.add("2");
        list.add(null);
        list.add("4");
        try {
            new ExtensionMatcher(list);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }
    
    /**
     * Checks whether the constructor ExtensionMatcher(List) properly throws
     * IllegalArgumentException for List argument containing non String elements.
     * 
     * @throws Exception in case anything goes wrong
     */
    public void testExtensionMatcher8() throws Exception {
        List list = new ArrayList();
        list.add("1");
        list.add(new Object());
        list.add("4");
        try {
            new ExtensionMatcher(list);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Tests the match method with null argument. NullPointerException should be thrown.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testMatch() throws Exception {
        try {
            matcher.match((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

}
