/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.util.config.Property;
import junit.framework.TestCase;
import java.io.File;
import java.io.IOException;

/**
 * <p>
 * Unit test cases for BinaryFileMatcher.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class BinaryFileMatcherTests extends TestCase {

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/matcher/";

    /**
     * An BinaryFileMatcher instance to test.
     */
    private BinaryFileMatcher matcher = null;

    /**
     * Creates a BinaryFileMatcher instance for test.
     */
    protected void setUp() {
        matcher = new BinaryFileMatcher();
    }

    /**
     * <p>
     * Verifies the constructor - BinaryFileMatcher(String).
     * </p>
     */
    public void testBinaryFileMatcher1() {
        assertTrue("Unable to instantiate BinaryFileMatcher.",
            new BinaryFileMatcher() instanceof FileCategoryMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - BinaryFileMatcher(Property).
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testBinaryFileMatcher3() throws Exception {
        assertTrue("Unable to instantiate BinaryFileMatcher.",
            new BinaryFileMatcher(new Property("foo")) instanceof FileCategoryMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - BinaryFileMatcher(Property) with null argument.
     * NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testBinaryFileMatcher4() throws Exception {
        try {
            new BinaryFileMatcher((Property) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method with null argument. NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch1() throws Exception {
        try {
            matcher.match((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }


    /**
     * <p>
     * Tests the match method with invalid File. IOException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch2() throws Exception {
        try {
            matcher.match(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch3() throws Exception {
        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test1.txt")));
    }

    /**
     * <p>
     * Tests the match method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch4() throws Exception {
        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test2.txt")));
    }

    /**
     * <p>
     * Tests the match method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch5() throws Exception {
        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test1.bin")));
    }

    /**
     * <p>
     * Tests the match method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch6() throws Exception {
        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test2.bin")));
    }

    /**
     * <p>
     * Tests the match method. Validates an empty file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch7() throws Exception {
        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "empty")));
    }




    /**
     * <p>
     * Tests the isBinary method with null argument. NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary1() throws Exception {
        try {
            BinaryFileMatcher.isBinary((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the isBinary method with invalid File. IOException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary2() throws Exception {
        try {
            BinaryFileMatcher.isBinary(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary3() throws Exception {
        assertFalse("The result should be false", BinaryFileMatcher.isBinary(new File(BASE_PATH, "test1.txt")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary4() throws Exception {
        assertFalse("The result should be false", BinaryFileMatcher.isBinary(new File(BASE_PATH, "test2.txt")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary5() throws Exception {
        assertTrue("The result should be true", BinaryFileMatcher.isBinary(new File(BASE_PATH, "test1.bin")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary6() throws Exception {
        assertTrue("The result should be true", BinaryFileMatcher.isBinary(new File(BASE_PATH, "test2.bin")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates an empty file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary7() throws Exception {
        assertFalse("The result should be false", BinaryFileMatcher.isBinary(new File(BASE_PATH, "empty")));
    }
}
