/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.TestHelper;
import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;
import junit.framework.TestCase;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;


/**
 * <p>
 * Unit test cases for TypeNameMatcher.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class TypeNameMatcherTests extends TestCase {
    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.matcher.unittest";

    /**
     * The config file for this test.
     */
    private static final String CONFIG_FILE = "matcher/matcher_config.xml";

    /**
     * The namespace for Magic Numbers component.
     */
    private static final String MAGIC_NUMBERS_NAMESPACE = "com.topcoder.file.type.MagicNumbers.xml";

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/matcher/";

    /**
     * An TypeNameMatcher instance to test.
     */
    private TypeNameMatcher matcher = null;

    /**
     * Load the configuration before testing.
     *
     * @throws Exception to JUnit
     */
    protected void setUp() throws Exception {
        TestHelper.loadConfigFile(CONFIG_FILE, NAMESPACE);
        TestHelper.removeNamespace(MAGIC_NUMBERS_NAMESPACE);
        matcher = new TypeNameMatcher("GIF image");
    }

    /**
     * Remove the configuration after testing.
     *
     * @throws Exception to JUnit
     */
    protected void tearDown() throws Exception {
        TestHelper.removeNamespace(NAMESPACE);
        TestHelper.removeNamespace(MAGIC_NUMBERS_NAMESPACE);
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(String).
     * </p>
     */
    public void testTypeNameMatcher1() {
        assertTrue("Unable to instantiate TypeNameMatcher.",
            new TypeNameMatcher("foo") instanceof FileTypeMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(String) with null argument. NullPointerException
     * should be thrown.
     * </p>
     */
    public void testTypeNameMatcher2() {
        try {
            new TypeNameMatcher((String) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(Property).
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher3() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "types_matcher");
        assertTrue("Unable to instantiate TypeNameMatcher.",
            new TypeNameMatcher(property) instanceof FileTypeMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(Property) with null argument.
     * NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher4() throws Exception {
        try {
            new TypeNameMatcher((Property) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(Property) with invalid property.
     * ConfigurationException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher5() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "types_matcher_invalid1");

        try {
            new TypeNameMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(Property) with invalid property.
     * ConfigurationException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher6() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "types_matcher_invalid2");

        try {
            new TypeNameMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(List).
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher7() throws Exception {
        List extensions = new ArrayList();
        extensions.add("foo");
        extensions.add("bar");
        assertTrue("Unable to instantiate TypeNameMatcher.",
            new TypeNameMatcher(extensions) instanceof FileTypeMatcher);
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(List) with null argument. NullPointerException
     * should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher8() throws Exception {
        try {
            new TypeNameMatcher((List) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(List) with empty list. IllegalArgumentException
     * should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher9() throws Exception {
        try {
            new TypeNameMatcher(new ArrayList());
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(List) with invalid list.
     * IllegalArgumentException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher10() throws Exception {
        List extensions = new ArrayList();
        extensions.add("foo");
        extensions.add(new ArrayList());

        try {
            new TypeNameMatcher(extensions);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(List) with invalid list.
     * IllegalArgumentException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher11() throws Exception {
        List extensions = new ArrayList();
        extensions.add("foo");
        extensions.add("");

        try {
            new TypeNameMatcher(extensions);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(List) with invalid list.
     * IllegalArgumentException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher12() throws Exception {
        List extensions = new ArrayList();
        extensions.add("foo");
        extensions.add(null);

        try {
            new TypeNameMatcher(extensions);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Verifies the constructor - TypeNameMatcher(Property) with invalid property.
     * ConfigurationException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testTypeNameMatcher13() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "types_matcher_invalid3");

        try {
            new TypeNameMatcher(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method with null argument. NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch1() throws Exception {
        try {
            matcher.match((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method. GIF file should be accepted.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch2() throws Exception {

        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test.GIF")));
    }

    /**
     * <p>
     * Tests the match method. BMP file should not be accepted.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch3() throws Exception {

        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test.BMP")));
    }

    /**
     * <p>
     * Tests the match method. JPG file should not be accepted.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch4() throws Exception {

        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test.JPG")));
    }

    /**
     * <p>
     * Tests the match method of multi-type matcher.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch5() throws Exception {
        // create a matcher that accepts GIF and JPEG files.
        List types = new ArrayList();
        types.add("GIF image");
        types.add("JPEG image");
        matcher = new TypeNameMatcher(types);

        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test.JPG")));
    }

    /**
     * <p>
     * Tests the match method of multi-type matcher.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch6() throws Exception {
        // create a matcher that accepts GIF and JPEG files.
        List types = new ArrayList();
        types.add("GIF image");
        types.add("JPEG image");
        matcher = new TypeNameMatcher(types);

        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test.GIF")));

    }

    /**
     * <p>
     * Tests the match method of multi-type matcher.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch7() throws Exception {
        // create a matcher that accepts GIF and JPEG files.
        List types = new ArrayList();
        types.add("GIF image");
        types.add("JPEG image");
        matcher = new TypeNameMatcher(types);

        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test.BMP")));

    }

    /**
     * <p>
     * Tests the match method of multi-type matcher.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch8() throws Exception {
        // create a matcher that accepts GIF and JPEG files.
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "types_matcher");
        matcher = new TypeNameMatcher(property);

        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test.JPG")));
    }

    /**
     * <p>
     * Tests the match method of multi-type matcher.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch9() throws Exception {
        // create a matcher that accepts GIF and JPEG files.
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "types_matcher");
        matcher = new TypeNameMatcher(property);

        assertTrue("The result should be true", matcher.match(new File(BASE_PATH, "test.GIF")));
    }

    /**
     * <p>
     * Tests the match method of multi-type matcher.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch10() throws Exception {
        // create a matcher that accepts GIF and JPEG files.
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE,
                "types_matcher");
        matcher = new TypeNameMatcher(property);

        assertFalse("The result should be false", matcher.match(new File(BASE_PATH, "test.BMP")));
    }

    /**
     * <p>
     * Tests the match method with invalid argument. IOException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch11() throws Exception {
        try {
            matcher.match(new File(BASE_PATH, "no_this_file"));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the match method with invalid argument. IOException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMatch12() throws Exception {
        try {
            matcher.match(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }
}
